=======================
Introduction
=======================

Jeju is intelligent provisioning system based on specification documents
Each S/W project has instruction documents like REAME.md, INSTALL.md ...

User can manually insall programs based on INSTALL.md
But the document may be ambiguously described.
Jeju can automatically install the software instructed by INSTALL.md

This can help developer and user.

=======================  
 Installation
=======================
Jeju is python program. This can be easily installed by pip.
If pip is not exist, run *apt-get install python-pip*


    pip install jeju


# Run example
You can easily test Jeju.


    jeju


If you want to know detailed options.


    jeju -h

